@@ -14,7 +14,7 @@ use strict;
 use warnings;
 require Forks::Super::Job::OS::Win32 if &IS_WIN32 || &IS_CYGWIN;
 
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 
 our $CPU_AFFINITY_CALLS = 0;
 our $OS_PRIORITY_CALLS = 0;
@@ -268,7 +268,7 @@ sub _get_number_of_processors_from_dmesg_bsd {
     my @d = grep { /Multiprocessor System Detected:/i } @dmesg;
     my $ncpus;
     if (@d > 0) {
-	_debug("dmesg_bsd contains:\n@d");
+	debug("dmesg_bsd contains:\n@d");
 	($ncpus) = $d[0] =~ /Detected: (\d+) CPUs/i;
     }
 
@@ -282,11 +282,11 @@ sub _get_number_of_processors_from_dmesg_bsd {
 		$d{$1}++;
 	    }
 	}
-	_debug("dmesg_bsd[2] contains:\n",@d);
+	debug("dmesg_bsd[2] contains:\n",@d);
 	$ncpus = scalar keys %d;
     }
     if (@dmesg < 50) {
-	_debug("full dmesg log:\n", @dmesg);
+	debug("full dmesg log:\n", @dmesg);
     }
     return $_num_procs_cached = $ncpus || 0;
 }
